;; -*- no-byte-compile: t; lexical-binding: nil -*-
(define-package "fennel-mode" "20251025.155"
  "A major-mode for editing Fennel code."
  '((emacs "26.1"))
  :url "https://git.sr.ht/~technomancy/fennel-mode"
  :commit "e903eb51980af60b517e160e16ad8f4435cfb5e0"
  :revdesc "e903eb51980a"
  :keywords '("languages" "tools"))
